import requests

class Hoang:
  def __init__(self, a, b):
    self.a = a
    self.b = b
  
  def nhan(self):
    print(int(self.a) * int(self.b))
  
  def info(self):
    print("""
    code test by : hoang
    fb : https://www.facebook.com/hoanglailaptrinh123
    """)

  